@@ -103,7 +103,7 @@ class Netlas:
             ret["error"] = f"Unexpected Stream error"
             raise APIError(ret["error"])
 
-    def query(
+    def search(
         self, query: str, datatype: str = "response", page: int = 0, indices: str = "", fields: str = None, exclude_fields: bool = False
     ) -> dict:
         """Send search query to Netlas API
@@ -144,12 +144,14 @@ class Netlas:
         )
         return ret
 
+    query = search # for backward compatibility
+
     def count(self, query: str, datatype: str = "response", indices: str = "") -> dict:
         """Calculate total count of query string results
 
         :param query: Search query string
         :type query: str
-        :param datatype: Data type (choises: response, cert, domain), defaults to "response"
+        :param datatype: Data type (choises: response, cert, domain, whois-ip, whois-domain), defaults to "response"
         :type datatype: str, optional
         :param indices: Comma-separated IDs of selected data indices (can be retrieved by `indices` method), defaults to ""
         :type indices: str, optional
@@ -161,6 +163,10 @@ class Netlas:
             endpoint = "/api/certs_count/"
         elif datatype == "domain":
             endpoint = "/api/domains_count/"
+        elif datatype == "whois-ip":
+            endpoint = "/api/whois_ip_count/"
+        elif datatype == "whois-domain":
+            endpoint = "/api/whois_domains_count/"
         ret = self._request(endpoint=endpoint, params={
                             "q": query, "indices": indices})
         return ret
@@ -247,7 +253,7 @@ class Netlas:
         :type fields: str
         :param exclude_fields: Exclude fields from output (instead include), defaults to False
         :type exclude_fields: bool
-        :param datatype: Data type (choices: response, cert, domain), defaults to "response"
+        :param datatype: Data type (choices: response, cert, domain, whois-ip, whois-domain), defaults to "response"
         :type datatype: str, optional
         :param size: Download documents count, defaults to 10
         :type size: int, optional
@@ -261,6 +267,10 @@ class Netlas:
             endpoint = "/api/certs/download/"
         elif datatype == "domain":
             endpoint = "/api/domains/download/"
+        elif datatype == "whois-ip":
+            endpoint = "/api/whois_ip/download/"
+        elif datatype == "whois-domain":
+            endpoint = "/api/whois_domains/download/"
 
         for ret in self._stream_request(
             endpoint=endpoint,
